@@ -67,6 +67,9 @@ def get_user_legs(df, user_id, use_multiprocessing=True) -> pd.DataFrame:
     Returns:
         pandas.DataFrame: DataFrame of user's legs
     """
+    
+    tzinfo = df.tracked_at.iloc[0].tzinfo
+    
     res = []
     
     activities = df[df["detection"] == "activity"].index.values
@@ -124,5 +127,8 @@ def get_user_legs(df, user_id, use_multiprocessing=True) -> pd.DataFrame:
     res = res.sort_values(by='started_at')
     res = res.reset_index()
     res = res.drop(columns='index')
+    
+    res.started_at = res.started_at.dt.tz_localize(tzinfo)
+    res.finished_at = res.finished_at.dt.tz_localize(tzinfo)
 
     return res
\ No newline at end of file
