@@ -1,4 +1,4 @@
-from mobilipy import home_work
+from mobilipy import poi_detection
 from mobilipy import legs
 from mobilipy import mode_detection
 from mobilipy import preparation
@@ -20,6 +20,6 @@ def analyse(df, user_id) -> pd.DataFrame:
     route_clusters_detected = segmentation.segment(df_prepared)
     route_clusters_detected = mode_detection.mode_detection(route_clusters_detected)
     legs_user = legs.get_user_legs(route_clusters_detected, user_id)
-    home_work.detect_home_work(legs_user, df_prepared)
+    poi_detection.detect_home_work(legs_user, df_prepared)
         
     return legs_user
\ No newline at end of file
